#
# spec file for package qsynth
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2014 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           qsynth
Version:        0.5.0
Release:        lp151.2.4
Summary:        Graphical User Interface for fluidsynth
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Midi
URL:            https://qsynth.sourceforge.net/qsynth-index.html
Source:         https://sourceforge.net/projects/qsynth/files/qsynth/%{version}/qsynth-%{version}.tar.gz
Patch1:         qsynth-fix_desktop_file.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(fluidsynth) >= 0.80.0
Recommends:     %{name}-lang

%description
Qsynth is a fluidsynth GUI front-end application written in C++ around the Qt5
toolkit using Qt Designer.

%lang_package

%prep
%setup -q
%patch1 -p1

%build
export QT_HASH_SEED=0
%configure \
    --enable-system-tray \
    --enable-gradient
make %{?_smp_mflags}

%install
export QT_HASH_SEED=0
%make_install

%suse_update_desktop_file -r "%{name}" AudioVideo Midi

%find_lang %{name} --with-qt

%files
%doc ChangeLog
%license COPYING
%{_bindir}/qsynth
%{_datadir}/applications/qsynth.desktop
%{_datadir}/icons/*/*/apps/qsynth.png
%{_datadir}/metainfo
%{_datadir}/qsynth
%exclude %{_datadir}/qsynth/translations
%{_mandir}/man1/qsynth.1%{ext_man}
%{_mandir}/man1/qsynth.fr.1%{ext_man}

%files lang -f %{name}.lang
%{_datadir}/qsynth/translations

%changelog
* Tue Feb 20 2018 jengelh@inai.de
- Remove unrealized future visions from description.
* Tue Feb 20 2018 aloisio@gmx.com
- Update to version 0.5.0
  * Added *.SF3 to soundfont files filter on Setup > Soundfonts
    > Open... file dialog.
  * Increased Soundfont bank-offset limit to 16384 (was 128).
  * Desktop entry specification file is now finally independent
    from build/configure template chains.
  * Updated target path for freedesktop.org's AppStream metainfo
    file (formerly AppData).
  version 0.4.4
  * Added French man page (by Olivier Humbert, thanks).
  * Make builds reproducible byte for byte, by getting rid of
    the configure build date and time stamps.
  version 0.4.3
  * Fixed a potential crash on the singleton/unique application
    instance setup.
  * Almost complete overhaul on the configure script command
    line options, wrt. installation directories specification,
    eg. --prefix, --bindir, --libdir, --datadir and --mandir.
  * Late French (fr) translation update (by Olivier Humbert,
    thanks).
  version 0.4.2
  * Old "Start minimized to system tray" option returns to setup.
  * Dropped the --enable-qt5 from configure as found redundant
    given that's the build default anyway (suggestion by Guido
    Scholz, while for Qtractor, thanks).
  version 0.4.1
  * Dropped old "Start minimized to system tray" option from setup.
  * CMake script lists update (patch by Orcan Ogetbil, thanks).
  * Added application keywords to freedesktop.org's AppData.
  * System-tray icon context menu has been fixed/hacked to show up
    again on Plasma 5 (aka. KDE5) notifications status area.
  * Prevent x11extras module from use on non-X11/Unix plaforms.
  * Messages standard output capture has been improved in both ways
    a non-blocking pipe may get.
  * Regression fix for invalid system-tray icon dimensions reported
    by some desktop environment frameworks.
  version 0.4.0
  * Desktop environment session shutdown/logout management has been
    also adapted to Qt5 framework.
  * Single/unique application instance control adapted to Qt5/X11.
  * Output meter scale text color fixed on dark color schemes.
  * Prefer Qt5 over Qt4 by default with configure script.
  * Complete rewrite of Qt4 vs. Qt5 configure builds.
  * A new top-level widget window geometry state save and restore
    sub-routine is now in effect.
  * Fixed for some strict tests for Qt4 vs. Qt5 configure builds.
  * German (de) translation update (by Guido Scholz, thanks).
  version 0.3.9
  * Added application description as freedesktop.org's AppData.
  * New user preference option on whether to show the nagging
    'program will keep running in the system tray' message, on
    main window close.
  * Application close confirm warning is now raising the main
    window as visible and active for due top level display,
    especially applicable when minimized to the system tray.
  * A man page has been added.
  * Translations install directory change.
  * Allow the build system to include an user specified LDFLAGS.
  * Czech (cs) translation updated (by Pavel Fric, thanks).
- Refreshed qsynth-fix_desktop_file.patch
- Dropped qsynth-remove_build_timestamps.patch (no longer
  necessary)
- Switched to Qt5 build
- Split locale files into separate -lang subpackage
- Spec cleanup
* Sat Jan  4 2014 pascal.bleser@opensuse.org
- update to 0.3.8:
  * Serbian (sr) translation added
- changes from 0.3.7:
  * new French (fr) translation
  * reversed (mouse) scroll-wheel effect on dial knob widgets
  * MIDI bank select mode control added to engine setup dialog
  * main window is now brought to front and (re)activated when clicking on the
    system tray icon instead of just hiding it
* Thu Jan  5 2012 pascal.bleser@opensuse.org
- initial version (0.3.6)
